( cd usr/bin ; rm -rf msgfmt.py )
( cd usr/bin ; ln -sf /usr/lib/python2.4/site-packages/i18n/msgfmt.py msgfmt.py )
( cd usr/bin ; rm -rf pygettext.py )
( cd usr/bin ; ln -sf /usr/lib/python2.4/site-packages/i18n/pygettext.py pygettext.py )
( cd usr/bin ; rm -rf pynche )
( cd usr/bin ; ln -sf /usr/lib/python2.4/site-packages/pynche/pynche pynche )
( cd usr/bin ; rm -rf modulator )
( cd usr/bin ; ln -sf /usr/lib/python2.4/site-packages/modulator/modulator.py modulator )
( cd usr/doc/python-2.4.1 ; rm -rf Tools )
( cd usr/doc/python-2.4.1 ; ln -sf /usr/lib/python2.4/site-packages Tools )
